netapp_ontap.models.capacity_pool_response_records API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.capacity_pool_response_records`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class CapacityPoolResponseRecordsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the CapacityPoolResponseRecords object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `license_manager: LicenseManager GET POST PATCH`

    The license_manager field of the capacity_pool_response_records.

  `links: SelfLink GET`

    The links field of the capacity_pool_response_records.

  `nodes: List[CapacityPoolNodes] GET POST PATCH`

    Nodes in the cluster associated with this capacity pool.

  `serial_number: str GET POST PATCH`

    Serial number of the capacity pool license.

    Example: 390000100